storage — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »

# storage

`camelot.view.storage.` `create_stored_file`(parent, storage, on_finish, filter='All files (*)', remove_original=False, filename=None)

  Popup a QFileDialog, put the selected file in the storage and return the call on_finish with the StoredFile when done

  Parameters: | on_finish – function that will be called in the gui thread when

  the file is stored. the first argument of the function should be the StoredFile

  Parameters: | filename – if None, a dialog will pop up, asking the user for

  the file, otherwise a string with the name of the file to be stored

`camelot.view.storage.` `open_stored_file`(parent, stored_file)

  Open the stored file with the default system editor for this file type

`camelot.view.storage.` `save_stored_file`(parent, stored_file)

  Save a stored file as another file

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »

Comments
blog comments powered by Disqus